import React, { FC } from 'react';
import { Animated, Pressable, View } from 'react-native';
import { styles } from './styles';
import { AtomIcon, LabelSemiBoldText } from '../../../../atoms';
import { InfoListItemButtonModel } from '../../listItemModels';

export const IconTitleButton: FC<InfoListItemButtonModel> = ({
  text,
  Icon= AtomIcon,
  onClick,
  disabled= false,
}) => {
  const animated = new Animated.Value(1);
  const fadeIn = () => {
    Animated.timing(animated, {
      toValue: 0.4,
      duration: 100,
      useNativeDriver: true,
    }).start();
  };
  const fadeOut = () => {
    Animated.timing(animated, {
      toValue: 1,
      duration: 200,
      useNativeDriver: true,
    }).start();
  };

  return (
    <Pressable
      onPressIn={fadeIn}
      onPressOut={fadeOut}
      onPress={onClick}
      disabled={disabled}
    >
      <Animated.View
        style={[
          styles.iconTitleButton,
          disabled && styles.iconTitleButton.disabled,
          { opacity: animated },
        ]}
      >
        <View style={styles.iconTitleButtonIconContainer}>
          <Icon width={32} height={32} color={styles.iconTitleButtonIconColor.color} />
        </View>
        <View style={styles.iconTitleButtonTextContainer}>
          <LabelSemiBoldText
            numberOfLines={1}
            color={
              disabled
                ? styles.iconTitleButtonTextTitleColor.disabled.color
                : styles.iconTitleButtonTextTitleColor.color}
          >
            {text}
          </LabelSemiBoldText>
        </View>
      </Animated.View>
    </Pressable>
  );
};
