import React, { FC } from 'react';
import { Pressable, View, Animated } from 'react-native';
import { styles } from './styles';
import { AtomIcon, Body2MediumText, LabelSemiBoldText } from '../../../../atoms';
import { InfoListItemButtonModel } from '../../listItemModels';

export const IconTitleDescriptionButton: FC<InfoListItemButtonModel> = ({
  text,
  description,
  Icon= AtomIcon,
  onClick,
  disabled= false,
}) => {
  const animated = new Animated.Value(1);
  const fadeIn = () => {
    Animated.timing(animated, {
      toValue: 0.4,
      duration: 100,
      useNativeDriver: true,
    }).start();
  };
  const fadeOut = () => {
    Animated.timing(animated, {
      toValue: 1,
      duration: 200,
      useNativeDriver: true,
    }).start();
  };

  return (
    <Pressable
      onPressIn={fadeIn}
      onPressOut={fadeOut}
      onPress={onClick}
      disabled={disabled}
    >
      <Animated.View
        style={[
          styles.iconTitleDescriptionButton,
          disabled && styles.iconTitleDescriptionButton.disabled,
          { opacity: animated },
        ]}
      >
        <View style={styles.iconTitleDescriptionButtonIconContainer}>
          <Icon width={32} height={32} color={styles.iconTitleDescriptionButtonIconColor.color} />
        </View>
        <View style={styles.iconTitleDescriptionButtonTextContainer}>
          <LabelSemiBoldText
            numberOfLines={1}
            color={
              disabled
                ? styles.iconTitleDescriptionButtonTextTitleColor.disabled.color
                : styles.iconTitleDescriptionButtonTextTitleColor.color}
          >
            {text}
          </LabelSemiBoldText>
          <Body2MediumText
            numberOfLines={1}
            color={
              disabled
                ? styles.iconTitleDescriptionButtonTextDescriptionColor.disabled.color
                : styles.iconTitleDescriptionButtonTextDescriptionColor.color}
          >
            {description}
          </Body2MediumText>
        </View>
      </Animated.View>
    </Pressable>
  );
};
